@@ -88,11 +88,11 @@ class Form(SignalEvent, TabContent):
         return (self.model == model
             and self.res_id == attributes.get('res_id')
             and self.attributes.get('domain') == attributes.get('domain')
-            and (self.attributes.get('mode') or []) == (
-                attributes.get('mode') or [])
             and self.attributes.get('view_ids') == attributes.get('view_ids')
-            and self.attributes.get('context') == attributes.get('context')
-            and self.attributes.get('limit') == attributes.get('limit')
+            and (attributes.get('view_ids')
+                or (self.attributes.get('mode') or ['tree', 'form']) == (
+                    attributes.get('mode') or ['tree', 'form']))
+            and self.screen.local_context == attributes.get('context')
             and self.attributes.get('search_value') == (
                 attributes.get('search_value')))
 
@@ -508,14 +508,20 @@ class Form(SignalEvent, TabContent):
             if value == 'ok':
                 return self.sig_save(None)
             if value == 'ko':
-                return self.sig_reload(test_modified=False)
+                record_id = self.screen.current_record.id
+                if self.sig_reload(test_modified=False):
+                    if record_id < 0:
+                        return None
+                    elif self.screen.current_record:
+                        return record_id == self.screen.current_record.id
             return False
         return True
 
     def sig_close(self, widget=None):
         for dialog in reversed(self.dialogs[:]):
             dialog.destroy()
-        return self.modified_save()
+        modified_save = self.modified_save()
+        return True if modified_save is None else modified_save
 
     def _action(self, action, atype):
         action = action.copy()
